@@ -30,7 +30,7 @@ void Audio::createWav(QString filename)
         QString program = "flite"; //espeak
         QStringList arguments;
 
-        arguments << "-voice" << "slt" << "-f" << filename << "-o" << audio; //arguments << "-f" << filename << "-s" << "110" << "-v " << "en/en-rp" << -w << audio;
+        arguments << "-voice" << "kal16" << "-f" << filename << "-o" << audio; //arguments << "-f" << filename << "-s" << "110" << "-v " << "en/en-rp" << -w << audio;
         qDebug()<<arguments;
         QProcess *myProcess = new QProcess();
 
@@ -46,6 +46,7 @@ void Audio::createWav(QString filename)
         connect(music, SIGNAL(finished()), this, SLOT(audioFinished()));
 
         audioFile->close();
+        this->wavCreated();
     }
 
 }
