@@ -144,6 +144,8 @@ void MainWindow::on_mainWindowButton_clicked()
         player->hide();
     if (options->isVisible())
         options->hide();
+    this->ui->label->hide();
+    this->ui->label_2->hide();
 }
 
 void MainWindow::on_playlistsButton_clicked()
@@ -158,6 +160,8 @@ void MainWindow::on_playlistsButton_clicked()
         player->hide();
     if (options->isVisible())
         options->hide();
+    this->ui->label->hide();
+    this->ui->label_2->hide();
 }
 void MainWindow::on_playerButton_clicked()
 {
@@ -171,6 +175,8 @@ void MainWindow::on_playerButton_clicked()
         playlist->hide();
     if (options->isVisible())
         options->hide();
+    this->ui->label->hide();
+    this->ui->label_2->hide();
 }
 
 void MainWindow::article_selected(QTableWidgetItem *item)
