@@ -1,6 +1,7 @@
 #include "playlist.h"
 #include "ui_playlist.h"
 #include <QMap>
+#include <QPushButton>
 
 
 Playlist::Playlist(QWidget *parent) :
@@ -71,12 +72,14 @@ void Playlist::addToPlaylist(QString playlist, QString article)
 void Playlist::updateList()
 {
     this->ui->treeWidget->clear();
+    QPushButton *button = new QPushButton("Remove");
     QList<QTreeWidgetItem *> items;
 //    QList<QTreeWidgetItem *> removes;
     foreach(QString title, this->playlistlist->getPlaylistTitles())
     {
 
         QTreeWidgetItem *item = new QTreeWidgetItem(QStringList(title));
+        ui->treeWidget->setItemWidget(item, 0, button);
         QList<QTreeWidgetItem*> children;
 
   //      QTreeWidgetItem *itemRemove = new QTreeWidgetItem(QStringList("Remove"));
@@ -85,11 +88,12 @@ void Playlist::updateList()
 
         foreach (QString article, this->playlistlist->getPlaylistContent(title))
         {
-            children.append(new QTreeWidgetItem(QStringList(article)));
 
-     //       QTreeWidgetItem *temp = new QTreeWidgetItem(QStringList("Remove"));
+            QTreeWidgetItem *temp = new QTreeWidgetItem(QStringList(article));
+            ui->treeWidget->setItemWidget(temp, 0, new QPushButton("Remove"));
      //       temp->setData(1,Qt::DisplayRole, QVariant(article));
      //       removeChildren.append(temp);
+            children.append(temp);
 
         }
         item->addChildren(children);
