@@ -22,7 +22,7 @@ public:
 
 private slots:
     void on_treeWidget_itemClicked(QTreeWidgetItem *item, int column);
-    void on_treeWidget_itemPressed(QTreeWidgetItem *item, int column);
+    void on_treeWidget_itemDoubleClicked(QTreeWidgetItem *item, int column);
 
 signals:
     void articleSelected(QTreeWidgetItem *item, int column);
