@@ -55,15 +55,11 @@ void Playlists::removePlaylistItem(QString item, int column, QTreeWidgetItem *pa
 {
     QStringList items;
     items = playlists.take(parent->text(column));
-    int i = 0;
-    foreach (QString playlistItem, items)
+    if (items.contains(item))
     {
-        if (playlistItem == item)
-        {
-            items.removeAt(i);
-            break;
-        }
-        i ++;
+
+        items.removeOne(item);
+
     }
     playlists.insert(parent->text(column), items);
     if (playlistFile->open(QIODevice::WriteOnly))
